@@ -116,12 +116,15 @@ func TestAssertAbout(t *testing.T) {
 func TestAssertRange(t *testing.T) {
 	successfulAssert := successfulAssertion(t)
 	failingAssert := failingAssertion(t)
+	now := time.Now()
 
 	successfulAssert.Range(byte(9), byte(1), byte(22), "byte in range")
 	successfulAssert.Range(9, 1, 22, "int in range")
 	successfulAssert.Range(9.0, 1.0, 22.0, "float64 in range")
 	successfulAssert.Range('f', 'a', 'z', "rune in range")
 	successfulAssert.Range("foo", "a", "zzzzz", "string in range")
+	successfulAssert.Range(now, now.Add(-time.Hour), now.Add(time.Hour), "time in range")
+	successfulAssert.Range(time.Minute, time.Second, time.Hour, "duration in range")
 	successfulAssert.Range([]int{1, 2, 3}, 1, 10, "slice length in range")
 	successfulAssert.Range([3]int{1, 2, 3}, 1, 10, "array length in range")
 	successfulAssert.Range(map[int]int{3: 1, 2: 2, 1: 3}, 1, 10, "map length in range")
@@ -130,6 +133,8 @@ func TestAssertRange(t *testing.T) {
 	failingAssert.Range(1.0, 10.0, 20.0, "float64 out of range")
 	failingAssert.Range('a', 'x', 'z', "rune out of range")
 	failingAssert.Range("aaa", "uuuuu", "zzzzz", "string out of range")
+	failingAssert.Range(now, now.Add(time.Minute), now.Add(time.Hour), "time out of range")
+	failingAssert.Range(time.Second, time.Minute, time.Hour, "duration in range")
 	failingAssert.Range([]int{1, 2, 3}, 5, 10, "slice length out of range")
 	failingAssert.Range([3]int{1, 2, 3}, 5, 10, "array length out of range")
 	failingAssert.Range(map[int]int{3: 1, 2: 2, 1: 3}, 5, 10, "map length out of range")
@@ -146,6 +151,25 @@ func TestAssertContents(t *testing.T) {
 	failingAssert.Contents(4711, "foo")
 	failingAssert.Contents(4711, []interface{}{1, "2", 3, "4711", 5, 6, 7, 8, 9})
 	successfulAssert.Contents("4711", []interface{}{1, "2", 3, "4711", 5, 6, 7, 8, 9})
+	failingAssert.Contents("foobar", []byte("the quick brown fox jumps over the lazy dog"))
+}
+
+// TestAssertContentsPrint test the visualization of failing content tests.
+func TestAssertContentsPrint(t *testing.T) {
+	assert := audit.NewTestingAssertion(t, false)
+
+	assert.Logf("printing of failing content tests")
+	assert.Contents("foobar", []byte("the quick brown fox jumps over the lazy dog"), "test fails but passes, just visualization")
+	assert.Contents([]byte("foobar"), []byte("the quick brown ..."), "test fails but passes, just visualization")
+}
+
+// TestOffsetPrint test the correct visualization when printing
+// with offset.
+func TestOffsetPrint(t *testing.T) {
+	assert := audit.NewTestingAssertion(t, false)
+
+	// Log should reference line below (167).
+	failWithOffset(assert, "172")
 }
 
 // TestAssertSubstring tests the Substring() assertion.
@@ -237,7 +261,7 @@ func TestAssertEmpty(t *testing.T) {
 }
 
 // TestAssertNotEmpty tests the NotEmpty() assertion.
-func TestAsserNotEmpty(t *testing.T) {
+func TestAssertNotEmpty(t *testing.T) {
 	successfulAssert := successfulAssertion(t)
 	failingAssert := failingAssertion(t)
 
@@ -307,6 +331,38 @@ func TestAssertWait(t *testing.T) {
 	failingAssert.Wait(sigc, true, 100*time.Millisecond, "should timeout")
 }
 
+// TestAssertWaitTested tests the wait tested testing.
+func TestAssertWaitTested(t *testing.T) {
+	successfulAssert := successfulAssertion(t)
+	failingAssert := failingAssertion(t)
+	tester := func(v interface{}) error {
+		b, ok := v.(bool)
+		if !ok || b == false {
+			return errors.New("illegal value")
+		}
+		return nil
+	}
+
+	sigc := audit.MakeSigChan()
+	go func() {
+		time.Sleep(50 * time.Millisecond)
+		sigc <- true
+	}()
+	successfulAssert.WaitTested(sigc, tester, 100*time.Millisecond, "should be true")
+
+	go func() {
+		time.Sleep(50 * time.Millisecond)
+		sigc <- false
+	}()
+	failingAssert.WaitTested(sigc, tester, 100*time.Millisecond, "should be false")
+
+	go func() {
+		time.Sleep(200 * time.Millisecond)
+		sigc <- true
+	}()
+	failingAssert.WaitTested(sigc, tester, 100*time.Millisecond, "should timeout")
+}
+
 // TestAssertRetry tests the retry testing.
 func TestAssertRetry(t *testing.T) {
 	successfulAssert := successfulAssertion(t)
@@ -362,7 +418,7 @@ func TestValidationAssertion(t *testing.T) {
 	assert, failures := audit.NewValidationAssertion()
 
 	assert.True(true, "should not fail")
-	assert.True(false, "sould fail")
+	assert.True(false, "should fail")
 	assert.Equal(1, 2, "should fail")
 
 	if !failures.HasErrors() {
@@ -372,6 +428,44 @@ func TestValidationAssertion(t *testing.T) {
 		t.Errorf("wrong number of errors")
 	}
 	t.Log(failures.Error())
+
+	if len(failures.Details()) != 2 {
+		t.Errorf("wrong number of details")
+	}
+	details := failures.Details()
+	fn, l, f := details[0].Location()
+	tt := details[0].Test()
+	if fn != "asserts_test.go" || l != 421 || f != "TestValidationAssertion" {
+		t.Errorf("wrong location of first detail: %d", l)
+	}
+	if tt != audit.True {
+		t.Errorf("wrong test type of first detail: %v", tt)
+	}
+	fn, l, f = details[1].Location()
+	tt = details[1].Test()
+	if fn != "asserts_test.go" || l != 422 || f != "TestValidationAssertion" {
+		t.Errorf("wrong location of second detail: %d", l)
+	}
+	if tt != audit.Equal {
+		t.Errorf("wrong test type of second detail: %v", tt)
+	}
+}
+
+// TestSetFailable tests the setting of the failable
+// to the one of a sub-test.
+func TestSetFailable(t *testing.T) {
+	successfulAssert := successfulAssertion(t)
+	failingAssert := failingAssertion(t)
+
+	t.Run("success", func(t *testing.T) {
+		defer successfulAssert.SetFailable(t)()
+		successfulAssert.True(true)
+	})
+
+	t.Run("fail", func(t *testing.T) {
+		defer failingAssert.SetFailable(t)()
+		failingAssert.True(false)
+	})
 }
 
 //--------------------
@@ -383,6 +477,10 @@ type metaFailer struct {
 	fail bool
 }
 
+func (f *metaFailer) IncrCallstackOffset() func() {
+	return func() {}
+}
+
 func (f *metaFailer) Logf(format string, args ...interface{}) {
 	f.t.Logf(format, args...)
 }
@@ -402,6 +500,18 @@ func (f *metaFailer) Fail(test audit.Test, obtained, expected interface{}, msgs
 	return f.fail
 }
 
+//--------------------
+// HELPER
+//--------------------
+
+// failWithOffset checks the offset increment.
+func failWithOffset(assert audit.Assertion, line string) {
+	restore := assert.IncrCallstackOffset()
+	defer restore()
+
+	assert.Fail("should fail referencing line " + line)
+}
+
 // successfulAssertion returns an assertion which doesn't expect a failing.
 func successfulAssertion(t *testing.T) audit.Assertion {
 	return audit.NewAssertion(&metaFailer{t, true})
